#!/usr/bin/env python
# coding=utf-8
import os
import re
import sys

from setuptools import setup


def read(*args):
    fpath = os.path.join(os.path.dirname(__file__), *args)
    if not os.path.exists(fpath):
        return ''
    return open(fpath).read()


def get_version():
    pattern = "^__version__ = ['\"]([^'\"]+)['\"]"
    return re.search(pattern, read('trmaid', '__init__.py'), re.MULTILINE).group(1)


if sys.argv[-1] == 'publish':
    os.system("python setup.py sdist upload")
    args = {'version': get_version()}
    print("You probably want to also tag the version now:")
    print("git tag -a %(version)s -m 'version %(version)s'" % args)
    print("git push --tags")
    sys.exit()


setup(
    name="trmaid",
    version=get_version(),
    author="Tanel Puhu",
    author_email="tanel@lusikas.com",
    description="Tool to maintain transmission (bittorrent) settings, add items from feeds and redis queues",
    keywords="transmission torrent",
    url="https://github.com/tanelpuhu/trmaid",
    packages=['trmaid'],
    install_requires=read('requirements.txt').strip().split('\n'),
    entry_points={
        'console_scripts': [
            'trmaid = trmaid.trmaid:main',
        ]},
    long_description=read('README.md'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        'Environment :: Console',
        "Topic :: Utilities",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
    ],
)
